import 'dart:convert';
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:movie_app/pages/movie_detail.dart';

import '../config.dart';

class MainPages extends StatefulWidget {
  @override
  _MainPagesState createState() => _MainPagesState();
}

class _MainPagesState extends State<MainPages> {
  var _populars = [];
  var _upComing = [];

  bool isLoading = true;

  void getPopularData(String apiKey) async {
    var response = await http.get(Uri.parse(
        "https://api.themoviedb.org/3/movie/popular?api_key=" +
            apiKey +
            "&language=en-US&page=1"));
    var jsonObject = jsonDecode(response.body);
    List<dynamic> listPopular = (jsonObject as Map<String, dynamic>)['results'];

    setState(() {
      _populars = listPopular;
      isLoading = false;
    });
  }

  void getUpComingData(String apiKey) async {
    var response = await http.get(Uri.parse(
        "https://api.themoviedb.org/3/movie/upcoming?api_key=" +
            apiKey +
            "&language=en-US&page=1"));
    var jsonObject = jsonDecode(response.body);
    List<dynamic> listUpComing =
        (jsonObject as Map<String, dynamic>)['results'];

    setState(() {
      _upComing = listUpComing;
      isLoading = false;
    });
  }

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    getPopularData(apiKey);
    getUpComingData(apiKey);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: backgroundColor,
        body: Stack(
          children: [
            ListView(
              children: [
                Padding(
                  padding: const EdgeInsets.all(10.0),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text(
                        "Hi, Dio Maulana",
                        style: TextStyle(
                            color: textColor,
                            fontSize: 20,
                            fontWeight: FontWeight.w800),
                      ),
                      ClipRRect(
                        child: Icon(
                          Icons.person,
                          color: textColor,
                          size: 30,
                        ),
                      )
                    ],
                  ),
                ),
                Align(
                  alignment: Alignment.center,
                  child: Container(
                    decoration: BoxDecoration(
                        color: Colors.transparent,
                        border: Border.all(color: Colors.grey),
                        borderRadius: BorderRadius.circular(20)),
                    margin: EdgeInsets.fromLTRB(10, 30, 10, 30),
                    padding: EdgeInsets.fromLTRB(10, 5, 5, 5),
                    // ignore: prefer_const_constructors
                    child: TextField(
                      style: TextStyle(color: textColor),
                      decoration: InputDecoration(
                          border: InputBorder.none,
                          icon: Icon(
                            Icons.search,
                            color: Colors.white30,
                          ),
                          labelText: "Search Movie",
                          labelStyle: TextStyle(color: Colors.white30)),
                    ),
                  ),
                ),
                Container(
                  margin: EdgeInsets.fromLTRB(10, 10, 10, 10),
                  child: Row(
                    children: [
                      Text(
                        "Popular",
                        style: titleText,
                      ),
                      Spacer(),
                      Text("See More", style: litleText),
                    ],
                  ),
                ),
                isLoading
                    ? Container(
                        margin: defaultCardPading,
                        height: 400,
                        child: ListView(
                          scrollDirection: Axis.horizontal,
                          children: [
                            for (int i = 0; i < 5; i++)
                              Center(
                                  child: Container(
                                      width: 120,
                                      height: 120,
                                      child: CircularProgressIndicator())),
                          ],
                        ),
                      )
                    : Container(
                        margin: defaultCardPading,
                        height: 400,
                        child: ListView(
                          scrollDirection: Axis.horizontal,
                          children: [
                            for (int i = 0; i < _populars.length; i++)
                              popularCard(
                                  context,
                                  "https://image.tmdb.org/t/p/w500" +
                                      _populars[i]['poster_path'],
                                  _populars[i]['title'],
                                  _populars[i]['vote_average'].toString(),
                                  _populars[i]['id'].toString()),
                          ],
                        ),
                      ),
                Container(
                  margin: defaultCardPading,
                  child: Row(
                    children: [
                      Text(
                        "Up coming",
                        style: titleText,
                      ),
                      Spacer(),
                      Text(
                        "See More",
                        style: litleText,
                      ),
                    ],
                  ),
                ),
                isLoading
                    ? Container(
                        margin: defaultCardPading,
                        height: 400,
                        child: ListView(
                          scrollDirection: Axis.horizontal,
                          children: [
                            for (int i = 0; i < 5; i++)
                              Center(
                                  child: Container(
                                      width: 120,
                                      height: 120,
                                      child: CircularProgressIndicator())),
                          ],
                        ),
                      )
                    : Container(
                        margin: EdgeInsets.fromLTRB(10, 10, 10, 0),
                        height: 400,
                        child: ListView(
                          scrollDirection: Axis.horizontal,
                          children: [
                            for (int i = 0; i < _upComing.length; i++)
                              popularCard(
                                  context,
                                  "https://image.tmdb.org/t/p/w500" +
                                      _upComing[i]['poster_path'],
                                  _upComing[i]['title'],
                                  _upComing[i]['vote_average'].toString(),
                                  _upComing[i]['id'].toString()),
                          ],
                        ),
                      ),
              ],
            )
          ],
        ));
  }

  Widget popularCard(BuildContext context, String image, String title,
      String rating, String id) {
    return GestureDetector(
      onTap: () {
        // Navigator.push(context, MaterialPageRoute(builder: (context) {
        // return detailMovie();
        // }));
        Navigator.pushNamed(
          context,
          '/detail',
          arguments: id,
        );
      },
      child: Container(
        margin: EdgeInsets.fromLTRB(10, 10, 10, 0),
        child: Column(
          children: [
            Material(
              elevation: 10,
              borderRadius: BorderRadius.circular(45),
              color: Colors.transparent,
              child: ClipRRect(
                borderRadius: BorderRadius.circular(45),
                child: Image(
                  image: NetworkImage(image),
                  fit: BoxFit.cover,
                  width: 200,
                  height: 300,
                ),
              ),
            ),
            SizedBox(
              height: 10,
            ),
            Container(
              width: 200,
              child: Text(
                title,
                textAlign: TextAlign.center,
                maxLines: 1,
                style: TextStyle(
                    fontSize: 14,
                    color: Colors.white,
                    fontWeight: FontWeight.w900,
                    overflow: TextOverflow.ellipsis),
              ),
            ),
            SizedBox(
              height: 5,
            ),
            Row(
              children: [
                Text(
                  rating,
                  maxLines: 1,
                  textAlign: TextAlign.center,
                  style: TextStyle(
                      color: Colors.grey,
                      fontSize: 12,
                      fontWeight: FontWeight.w500),
                ),
                SizedBox(
                  width: 5,
                ),
                Icon(
                  Icons.star,
                  color: Colors.yellow,
                  size: 14,
                )
              ],
            )
          ],
        ),
      ),
    );
  }
}
